Architecture Documentation
==========================

This section contains detailed architecture documentation for pyqt-reactive's
core systems and design patterns.

Core Form System
----------------

.. toctree::
   :maxdepth: 1

   parameter_form_service_architecture
   parameter_form_lifecycle
   parametric_widget_creation
   widget_protocol_system
   field_change_dispatcher

Service Layer
-------------

.. toctree::
   :maxdepth: 1

   ui_services_architecture
   service-layer-architecture

Widget Components
-----------------

.. toctree::
   :maxdepth: 1

   abstract_manager_widget
   abstract_table_browser
   list_item_preview_system
   scope_visual_feedback_system

Animation & Performance
-----------------------

.. toctree::
   :maxdepth: 1

   flash_animation_system
   flash_callback_system
   gui_performance_patterns
   cross_window_update_optimization

